Index: src/ia32/lithium-codegen-ia32.cc |
diff --git a/src/ia32/lithium-codegen-ia32.cc b/src/ia32/lithium-codegen-ia32.cc |
index aab2c9671eb37a5a37769a887e953ee039d1954b..0dbe3da13d3f1b4f59bfd2b1f31a1fbaf84c6eaa 100644 |
--- a/src/ia32/lithium-codegen-ia32.cc |
+++ b/src/ia32/lithium-codegen-ia32.cc |
@@ -297,7 +297,7 @@ bool LCodeGen::GeneratePrologue() { |
__ CallStub(&stub); |
} else { |
__ push(edi); |
- __ CallRuntime(Runtime::kNewFunctionContext, 1); |
+ __ CallRuntime(Runtime::kHiddenNewFunctionContext, 1); |
} |
RecordSafepoint(Safepoint::kNoLazyDeopt); |
// Context is returned in eax. It replaces the context passed to us. |
@@ -3739,7 +3739,7 @@ void LCodeGen::DoDeclareGlobals(LDeclareGlobals* instr) { |
__ push(esi); // The context is the first argument. |
__ push(Immediate(instr->hydrogen()->pairs())); |
__ push(Immediate(Smi::FromInt(instr->hydrogen()->flags()))); |
- CallRuntime(Runtime::kDeclareGlobals, 3, instr); |
+ CallRuntime(Runtime::kHiddenDeclareGlobals, 3, instr); |
} |
@@ -3863,7 +3863,7 @@ void LCodeGen::DoDeferredMathAbsTaggedHeapNumber(LMathAbs* instr) { |
// Slow case: Call the runtime system to do the number allocation. |
__ bind(&slow); |
- CallRuntimeFromDeferred(Runtime::kAllocateHeapNumber, 0, |
+ CallRuntimeFromDeferred(Runtime::kHiddenAllocateHeapNumber, 0, |
instr, instr->context()); |
// Set the pointer to the new heap number in tmp. |
if (!tmp.is(eax)) __ mov(tmp, eax); |
@@ -5024,11 +5024,11 @@ void LCodeGen::DoDeferredNumberTagIU(LInstruction* instr, |
// NumberTagI and NumberTagD use the context from the frame, rather than |
// the environment's HContext or HInlinedContext value. |
// They only call Runtime::kAllocateHeapNumber. |
// The corresponding HChange instructions are added in a phase that does |
// not have easy access to the local context. |
__ mov(esi, Operand(ebp, StandardFrameConstants::kContextOffset)); |
- __ CallRuntimeSaveDoubles(Runtime::kAllocateHeapNumber); |
+ __ CallRuntimeSaveDoubles(Runtime::kHiddenAllocateHeapNumber); |
RecordSafepointWithRegisters( |
instr->pointer_map(), 0, Safepoint::kNoLazyDeopt); |
__ StoreToSafepointRegisterSlot(reg, eax); |
@@ -5099,11 +5099,11 @@ void LCodeGen::DoDeferredNumberTagD(LNumberTagD* instr) { |
PushSafepointRegistersScope scope(this); |
// NumberTagI and NumberTagD use the context from the frame, rather than |
// the environment's HContext or HInlinedContext value. |
// They only call Runtime::kAllocateHeapNumber. |
// The corresponding HChange instructions are added in a phase that does |
// not have easy access to the local context. |
__ mov(esi, Operand(ebp, StandardFrameConstants::kContextOffset)); |
- __ CallRuntimeSaveDoubles(Runtime::kAllocateHeapNumber); |
+ __ CallRuntimeSaveDoubles(Runtime::kHiddenAllocateHeapNumber); |
RecordSafepointWithRegisters( |
instr->pointer_map(), 0, Safepoint::kNoLazyDeopt); |
__ StoreToSafepointRegisterSlot(reg, eax); |
@@ -5926,7 +5926,7 @@ void LCodeGen::DoDeferredAllocate(LAllocate* instr) { |
__ push(Immediate(Smi::FromInt(flags))); |
CallRuntimeFromDeferred( |
- Runtime::kAllocateInTargetSpace, 2, instr, instr->context()); |
+ Runtime::kHiddenAllocateInTargetSpace, 2, instr, instr->context()); |
__ StoreToSafepointRegisterSlot(result, eax); |
} |
@@ -5959,7 +5959,7 @@ void LCodeGen::DoRegExpLiteral(LRegExpLiteral* instr) { |
__ push(Immediate(Smi::FromInt(instr->hydrogen()->literal_index()))); |
__ push(Immediate(instr->hydrogen()->pattern())); |
__ push(Immediate(instr->hydrogen()->flags())); |
- CallRuntime(Runtime::kMaterializeRegExpLiteral, 4, instr); |
+ CallRuntime(Runtime::kHiddenMaterializeRegExpLiteral, 4, instr); |
__ mov(ebx, eax); |
__ bind(&materialized); |
@@ -5971,7 +5971,7 @@ void LCodeGen::DoRegExpLiteral(LRegExpLiteral* instr) { |
__ bind(&runtime_allocate); |
__ push(ebx); |
__ push(Immediate(Smi::FromInt(size))); |
- CallRuntime(Runtime::kAllocateInNewSpace, 1, instr); |
+ CallRuntime(Runtime::kHiddenAllocateInNewSpace, 1, instr); |
__ pop(ebx); |
__ bind(&allocated); |
@@ -6005,7 +6005,7 @@ void LCodeGen::DoFunctionLiteral(LFunctionLiteral* instr) { |
__ push(Immediate(instr->hydrogen()->shared_info())); |
__ push(Immediate(pretenure ? factory()->true_value() |
: factory()->false_value())); |
- CallRuntime(Runtime::kNewClosure, 3, instr); |
+ CallRuntime(Runtime::kHiddenNewClosure, 3, instr); |
} |
} |
@@ -6185,7 +6185,7 @@ void LCodeGen::DoDummyUse(LDummyUse* instr) { |
void LCodeGen::DoDeferredStackCheck(LStackCheck* instr) { |
PushSafepointRegistersScope scope(this); |
__ mov(esi, Operand(ebp, StandardFrameConstants::kContextOffset)); |
- __ CallRuntimeSaveDoubles(Runtime::kStackGuard); |
+ __ CallRuntimeSaveDoubles(Runtime::kHiddenStackGuard); |
RecordSafepointWithLazyDeopt( |
instr, RECORD_SAFEPOINT_WITH_REGISTERS_AND_NO_ARGUMENTS); |
ASSERT(instr->HasEnvironment()); |
@@ -5024,11 +5024,11 @@ void LCodeGen::DoDeferredNumberTagIU(LInstruction* instr, |
// NumberTagI and NumberTagD use the context from the frame, rather than |
// the environment's HContext or HInlinedContext value. |
- // They only call Runtime::kAllocateHeapNumber. |
+ // They only call Runtime::kHiddenAllocateHeapNumber. |
// The corresponding HChange instructions are added in a phase that does |
// not have easy access to the local context. |
@@ -5099,11 +5099,11 @@ void LCodeGen::DoDeferredNumberTagD(LNumberTagD* instr) { |
// NumberTagI and NumberTagD use the context from the frame, rather than |
// the environment's HContext or HInlinedContext value. |
- // They only call Runtime::kAllocateHeapNumber. |
+ // They only call Runtime::kHiddenAllocateHeapNumber. |
// The corresponding HChange instructions are added in a phase that does |
// not have easy access to the local context. |